@@ -4,25 +4,10 @@ require "net/imap"
 require "test/unit"
 require_relative "fake_server"
 
-class IMAPCapabilitiesTest < Test::Unit::TestCase
+class IMAPCapabilitiesTest < Net::IMAP::TestCase
 
   include Net::IMAP::FakeServer::TestHelper
 
-  def setup
-    Net::IMAP.config.reset
-    @do_not_reverse_lookup = Socket.do_not_reverse_lookup
-    Socket.do_not_reverse_lookup = true
-    @threads = []
-  end
-
-  def teardown
-    if !@threads.empty?
-      assert_join_threads(@threads)
-    end
-  ensure
-    Socket.do_not_reverse_lookup = @do_not_reverse_lookup
-  end
-
   test "#capabilities returns cached CAPABILITY data" do
     with_fake_server do |server, imap|
       imap.clear_cached_capabilities
